@@ -118,7 +118,9 @@ gint main(gint argc, gchar** argv)
 	GOptionContext *context;
 
 	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+#endif
 	textdomain(GETTEXT_PACKAGE);
 
 	context = g_option_context_new(_("- a simple frontend to easily connect to remote filesystems"));
@@ -131,7 +133,7 @@ gint main(gint argc, gchar** argv)
 	if (show_version)
 	{
 		g_print("%s %s\n\n", PACKAGE, VERSION);
-		g_print("%s\n", "Copyright \302\251 2008-2023 The Xfce development team");
+		g_print("%s\n", "Copyright \302\251 2008-2024 The Xfce development team");
 		g_print("\n");
 
 		return EXIT_SUCCESS;
